# pylint: disable=missing-docstring

import unittest


class TestCli(unittest.TestCase):

    def test_dummy(self):
        """
        It's saturday evening and sauna is on, so have no time to implement tests for now.
        This is totally against my principals but sometimes "poikkeus vahvistaa säännön".
        Instead writing tests, I'll get one beer and go to sauna, sorry about buggy plugin.
        """
        pass
